/*
 * (c) Bernd Müller & Harald Wehr, www.jpainfo.de
 */
package de.jpainfo.test;

import java.io.File;
import java.io.FilenameFilter;
import java.io.IOException;
import java.lang.reflect.Method;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.Arrays;

public class Provider {

	private static final boolean DEBUG = true;
	private static final String LIBS_PROJECT = "../libs/";  // Pfad zum Bibliothekenprojekt
	private static final FilenameFilter JAR_FILTER = new FilenameFilter() {
		@Override
		public boolean accept(File dir, String name) {
			return name.endsWith(".jar");
		}
	};
	
	public static void select(String provider) {
		if (provider.equals("eclipselink") || provider.equals("hibernate") || provider.equals("openjpa")) {
			File[] providerJars = new File(LIBS_PROJECT + provider).listFiles(JAR_FILTER);
			File[] jdbcJars = new File(LIBS_PROJECT + "jdbc").listFiles(JAR_FILTER);
			ArrayList<File> jars = new ArrayList<File>(Arrays.asList(providerJars));
			jars.addAll(Arrays.asList(jdbcJars));
			for (File jar : jars) {
				try {
					addUrl(jar.toURI().toURL());
					if (DEBUG) {
						System.out.println("Hinzugefügt: " + jar.getCanonicalPath());
					}
				} catch (Exception e) {
					System.err.println("Probleme mit SystemClassLoader");
				}
			}
		} else {
			System.err.println("Kein bekannter Provider");
		}
		
	}
	
	
	public static void addUrl(URL url) throws IOException {
	    URLClassLoader sysloader = (URLClassLoader) ClassLoader.getSystemClassLoader();
	    try {
	        Method method = URLClassLoader.class.getDeclaredMethod("addURL", URL.class);
	        method.setAccessible(true);
	        method.invoke(sysloader, new Object[] { url });
	    } catch (Exception t) {
	    	throw new IOException("Probleme mit SystemClassLoader");
	    }
	}

	
}
